TimingTest

Struct TimingTest 

pub struct TimingTest { /* private fields */ }
Builder for timing tests.

Implementations

Source

impl TimingTest

pub fn new(name: impl Into<String>) -> Self

Create a new timing test.

pub fn iterations(self, n: usize) -> Self

Set the number of iterations.

pub fn warmup(self, n: usize) -> Self

Set the number of warmup iterations.

pub fn threshold(self, t: f64) -> Self

Set the t-value threshold.

pub fn with_percentile_cropping(self, percent: f64) -> Self

Enable symmetric percentile cropping.

Removes the specified percentage of samples from both ends of the timing distribution to reduce noise from outliers.

pub fn with_asymmetric_cropping(self, low: f64, high: f64) -> Self

Enable asymmetric percentile cropping.

pub fn run<F, R>(self, f: F) -> TimingResult
where F: FnMut(Class) -> R,

Run the timing test.

The function f should take a Class and return some result. Timing measurements are taken for both classes and compared.

pub fn run_online<F, R>(self, f: F) -> TimingResult
where F: FnMut(Class) -> R,

Run with online statistics (memory-efficient for large iterations).